/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.core.descriptor;

import java.util.Map;

import org.w3c.dom.Element;

import org.apache.muse.core.Environment;
import org.apache.muse.util.ReflectUtils;
import org.apache.muse.util.xml.XmlUtils;
import org.apache.muse.ws.addressing.soap.SoapFault;

/**
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class SimpleCapabilityDescriptor implements CapabilityDescriptor
{
    private CapabilityDefinition _definition = null;
    
    protected Class createImplementationClass(Element xml, Environment env)
    {
        String className = XmlUtils.getElementText(xml, DescriptorConstants.JAVA_CAPABILITY_QNAME);
        
        //
        // null return value necessary to support default/required capability 
        // implementations for some vendors
        //
        if (className == null)
            return null;
        
        return ReflectUtils.getClass(className, env.getClassLoader());
    }
    
    protected InitParamDescriptor createInitParamDescriptor()
    {
        return new SimpleInitParamDescriptor();
    }
    
    protected PersistenceDefinition createPersistence(Element xml, Environment env)
        throws SoapFault
    {
        Element persistenceXML = XmlUtils.getElement(xml, DescriptorConstants.PERSISTENCE_QNAME);
        
        if (persistenceXML == null)
            return null;
        
        PersistenceDescriptor desc = createPersistenceDescriptor();
        desc.load(persistenceXML, env);
        
        return desc.getPersistenceDefinition();
    }
    
    protected PersistenceDescriptor createPersistenceDescriptor()
    {
        return new SimplePersistenceDescriptor();
    }
    
    protected String createURI(Element xml)
    {
        return XmlUtils.getElementText(xml, DescriptorConstants.CAPABILITY_URI_QNAME);
    }
    
    public CapabilityDefinition getCapabilityDefinition()
    {
        return _definition;
    }
    
    public void load(Element xml, Environment environment)
        throws SoapFault
    {
        String uri = createURI(xml);
        Class implClass = createImplementationClass(xml, environment);
        PersistenceDefinition persistence = createPersistence(xml, environment);
        
        InitParamDescriptor paramDesc = createInitParamDescriptor();
        paramDesc.load(xml);
        Map parameters = paramDesc.getInitializationParameters();
        
        _definition = new CapabilityDefinition();
        _definition.setURI(uri);
        _definition.setImplementationClass(implClass);
        _definition.setPersistenceDefinition(persistence);
        _definition.setInitializationParameters(parameters);
    }
}
