/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
 
package org.apache.muse.core.descriptor;

import java.util.Map;

import org.w3c.dom.Element;

import org.apache.muse.core.Environment;
import org.apache.muse.core.Persistence;
import org.apache.muse.core.routing.RouterPersistence;
import org.apache.muse.util.ReflectUtils;
import org.apache.muse.util.messages.Messages;
import org.apache.muse.util.messages.MessagesFactory;
import org.apache.muse.util.xml.XmlUtils;
import org.apache.muse.ws.addressing.soap.SoapFault;

/**
 * 
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class SimplePersistenceDescriptor implements PersistenceDescriptor
{
    //
    // Used to lookup all exception messages
    //
    private static Messages _MESSAGES = 
        MessagesFactory.get(SimplePersistenceDescriptor.class);
        
    private PersistenceDefinition _definition = null;
    
    protected InitParamDescriptor createInitParamDescriptor()
    {
        return new SimpleInitParamDescriptor();
    }
    
    protected Class createPersistenceClass(Element persistenceXML, Environment env)
    {
        String className = XmlUtils.getElementText(persistenceXML, DescriptorConstants.JAVA_PERSISTENCE_QNAME);
        
        ClassLoader loader = env.getClassLoader();
        Class theClass = ReflectUtils.getClass(className, loader);
        
        //
        // make sure this class is an instance of RouterPersistence
        //
        if (!Persistence.class.isAssignableFrom(theClass))
        {
            Object[] filler = { className, RouterPersistence.class.getName() };
            String message = _MESSAGES.get("IncorrectPersistenceRoot", filler);
            throw new RuntimeException(message);
        }
        
        return theClass;
    }

    protected String createPersistenceLocation(Element persistenceXML)
    {
        return XmlUtils.getElementText(persistenceXML, DescriptorConstants.PERSISTENCE_LOCATION_QNAME);
    }

    public PersistenceDefinition getPersistenceDefinition()
    {
        return _definition;
    }
    
    public void load(Element persistenceXML, Environment env) 
        throws SoapFault
    {
        Class theClass = createPersistenceClass(persistenceXML, env);
        String location = createPersistenceLocation(persistenceXML);
        
        InitParamDescriptor paramDesc = createInitParamDescriptor();
        paramDesc.load(persistenceXML);
        Map parameters = paramDesc.getInitializationParameters();
        
        _definition = new PersistenceDefinition();
        _definition.setPersistenceClass(theClass);
        _definition.setPersistenceLocation(location);
        _definition.setInitializationParameters(parameters);
    }
}
