/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.core.platform;

import org.apache.muse.core.Initialization;
import org.apache.muse.core.InitializationFailure;
import org.apache.muse.core.Shutdown;
import org.apache.muse.core.routing.ResourceRouter;

/**
 * 
 * IsolationLayer is the web service that is registered with the service 
 * container; it is the starting point for all Muse application initialization 
 * and request handling events. The behavior of this component is mostly 
 * defined by an instance of 
 * {@linkplain org.apache.muse.core.descriptor.DeploymentDescriptor DeploymentDescriptor}, 
 * although concrete isolation layers will also rely on platform-specific 
 * deployment artifacts and APIs.
 * <br><br>
 * Every concrete isolation layer delegates control of request handling to a 
 * {@linkplain org.apache.muse.core.routing.ResourceRouter ResourceRouter}. 
 * The role of the isolation layer is to initialize this router and to take the SOAP 
 * data from platform-specific APIs and convert into a generic form so that 
 * the router can do its work in a platform-independent way. The net of this 
 * is that a user's manageable resource code can be ported from platform to 
 * platform without being modified or recompiled.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface IsolationLayer 
    extends Initialization, InitializationFailure, Shutdown
{
    /**
     * 
     * @return The router instance that is responsible for delegating SOAP 
     *         requests in a platform-independent way.
     *
     */
    ResourceRouter getRouter();
}
