/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.core.serializer;

import java.net.MalformedURLException;
import java.net.URL;

import javax.xml.namespace.QName;

import org.w3c.dom.Element;

import org.apache.muse.util.xml.XmlUtils;
import org.apache.muse.ws.addressing.soap.SoapFault;

/**
 *
 * UrlSerializer transforms java.net.URL to XML and back.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class UrlSerializer implements Serializer
{
    public Object fromXML(Element xml)
        throws SoapFault
    {
        String url = XmlUtils.extractText(xml);
        
        try
        {
            return new URL(url);
        }
        
        catch (MalformedURLException error)
        {
            throw new SoapFault(error.getMessage(), error);
        }
    }
    
    public Class getSerializableType()
    {
        return URL.class;
    }
    
    public Element toXML(Object obj, QName qname)
    {
        return XmlUtils.createElement(qname, obj);
    }
}
