/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.core.platform.osgi.util;

import java.io.File;
import java.util.HashMap;
import org.osgi.framework.Bundle;

/**
 * BundleRootHelper allows bundles to specify a file system root for use
 * in loading persistence data, etc. 
 * 
 * @author Joel Hawkins (joelh)
 *
 */
public class BundleRootHelper {

	private static HashMap bundleToRootMap = new HashMap();
	private static HashMap bundleToContextMap = new HashMap();
	
	/**
	 * registers a File System root for a particular bundle
	 * @param bundle
	 * @param root
	 */
	public static void registerRoot(Bundle bundle, File root){
		synchronized(bundleToRootMap){
			bundleToRootMap.put(bundle, root);
		}
	}
	
	/**
	 * registers a Muse context (from the manifest)for a particular bundle
	 * @param bundle
	 * @param root
	 */
	public static void registerContext(Bundle bundle, String context){
		synchronized(bundleToContextMap){
			bundleToContextMap.put(bundle, context);
		}
	}

	/**
	 * returns the registerd file system root 
	 * @param bundle
	 * @return the root File registered for the specified bundle, or null if the 
	 * bundle did not register a file system root
	 * @see org.apache.muse.core.platform.osgi.axis2.Axis2Environment#getRealDirectory()
	 */
	public static File getRootForBundle(Bundle bundle){
		synchronized(bundleToRootMap){
			return (File) bundleToRootMap.get(bundle);
		}
	}

	/**
	 * returns the registerd file system root 
	 * @param bundle
	 * @return the context registered for the specified bundle, or null if the 
	 * bundle did not register a context
	 */
	public static String getContextForBundle(Bundle bundle){
		synchronized(bundleToContextMap){
			return (String) bundleToContextMap.get(bundle);
		}
	}
}
