package org.apache.muse.core.platform.osgi.mini.internal;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;

import org.apache.muse.core.Environment;
import org.apache.muse.core.platform.mini.MiniEnvironment;
import org.apache.muse.core.platform.mini.MiniIsolationLayer;
import org.apache.muse.core.platform.osgi.util.OSGiReflectUtilHelper;
import org.apache.muse.util.ReflectUtils;

public class OSGiMiniIsolationLayer extends MiniIsolationLayer  {

	protected boolean initializing = false;
	protected boolean initialized = false;

	public OSGiMiniIsolationLayer(HttpServletRequest initialRequest, ServletContext initialContext){
    	super(initialRequest,initialContext);
    }
	
    protected Environment createEnvironment()
    {
        return new OSGiMiniEnvironment(getInitialRequest(), getInitialContext());
    }
	

	/**
	 * performs initialzation of the IsolationLayer, and installs the
	 * <code>OSGiReflectUtilHelper</code> singleton as the <code>ReflectUtils</code>
	 * helper.
	 * 
	 * @see ReflectUtils
	 * @see OSGiReflectUtilHelper
	 */
	public void initialize() {

		if(initializing) return;

		ClassLoader prev = Thread.currentThread().getContextClassLoader();
		try {
			initializing = true;
			ReflectUtils.setHelper(OSGiReflectUtilHelper.getDefault());
			Thread.currentThread().setContextClassLoader(
					OSGiMiniIsolationLayer.class.getClassLoader());
			super.initialize();
			initialized = true;
		} catch (RuntimeException e) {
			e.printStackTrace();
			throw e;
		} finally {
			Thread.currentThread().setContextClassLoader(prev);
		}
	}

}
