/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.core.platform.axis2;

import org.apache.axiom.soap.SOAPBody;
import org.apache.axis2.context.MessageContext;
import org.apache.axis2.handlers.AbstractHandler;
import org.apache.muse.ws.addressing.WsaConstants;
import org.apache.muse.ws.addressing.soap.SoapConstants;

/**
 * 
 * This is an Axis2 handler that provides a WS-A Action URI for the response 
 * message based on the one that was included in the request message. Axis2 
 * does not provide a response URI that differs from the request URI. In cases 
 * where the operation results in a fault, the standard WS-A fault URI is used.
 *  
 * @author Mohammad Fakhar
 * @author Dan Jemiolo (danj)
 *
 */

public class ResponseActionHandler extends AbstractHandler
{
    private static final String REQUEST = "Request";
    private static final String RESPONSE = "Response";
    
    private void handleFault(MessageContext msgContext)
    {
        msgContext.setWSAAction(WsaConstants.FAULT_URI);
    }
    
    private void handleResponse(MessageContext msgContext)
    {
        String currentResponseAction = msgContext.getWSAAction();
        String realResponseAction = null;
        
        //
        // replace "Request" with "Response" if needed - if "Request" is 
        // not found, just tack on a "Response"
        //
        // NOTE: this logic is based on MessageHeaders.createReplyHeaders()
        //
        if (currentResponseAction.endsWith(REQUEST))
            realResponseAction = currentResponseAction.replaceAll(REQUEST, RESPONSE);

        else
            realResponseAction = currentResponseAction + RESPONSE;

        msgContext.setWSAAction(realResponseAction);

    }

    public InvocationResponse invoke(MessageContext msgContext)
    {
        SOAPBody soapBody = msgContext.getEnvelope().getBody();
        
        //
        // if the operation was a fault, there will always be 
        // a SOAP 1.2 Fault element in the response body
        //
    	if ((soapBody.getFirstChildWithName(SoapConstants.FAULT_QNAME) != null))
    		handleFault(msgContext);
        
    	else
    		handleResponse(msgContext);
        
        return InvocationResponse.CONTINUE;
    }
}
