/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.addressing;

import java.net.URI;

import javax.xml.namespace.QName;

/**
 *
 * WsaUtils is a collection of properties that is useful when programming 
 * against the WS-Addressing spec. This class uses WS-A 1.0 (08/2005).
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class WsaConstants
{
    /**
     * 
     * The namespace of the WS-A 1.0 spec
     * 
     */
    public static final String NAMESPACE_URI = "http://www.w3.org/2005/08/addressing";
    
    public static final String PREFIX = "wsa";
    
    /**
     * 
     * The default URI for WS-A reference parameters.
     * 
     */
    public static final String MUSE_ADDRESSING_URI = "http://ws.apache.org/muse/addressing";
    
    public static final String MUSE_ADDRESSING_PREFIX = "muse-wsa";
    
    /**
     * 
     * The URI for anonymous EPRs.
     * 
     */
    public static final String ANONYMOUS_URI = NAMESPACE_URI + "/role/anonymous";
    
    public static final QName ACTION_QNAME = 
        new QName(NAMESPACE_URI, "Action", PREFIX);

    public static final QName ADDRESS_QNAME = 
        new QName(NAMESPACE_URI, "Address", PREFIX);
    
    //
    // This is the default identifier used for the implied resource pattern. 
    // This is preferred to something like MUWS P1 ResourceId because it is 
    // generic to all resource types.
    //
    public static final QName DEFAULT_RESOURCE_ID_QNAME = 
        new QName(MUSE_ADDRESSING_URI, "ResourceId", MUSE_ADDRESSING_PREFIX);    
    
    /**
     * 
     * The standard EndpointReference QName - note that EPRs are <b>not</b> 
     * required to use this as their root element QName when serialized to XML.
     * 
     */
    public static final QName EPR_QNAME = 
        new QName(NAMESPACE_URI, "EndpointReference", PREFIX);
    
    /**
     * 
     * The name of the XSD EPR type. For EPR XML instances, use EPR_QNAME.
     * 
     */
    public static final QName EPR_TYPE_QNAME = 
        new QName(NAMESPACE_URI, "EndpointReferenceType", PREFIX);
    
    public static final QName FAULT_TO_QNAME = 
        new QName(NAMESPACE_URI, "FaultTo", PREFIX);

    /**
     * 
     * The wsa:Action that all fault messages should use.
     * 
     */
    public static final String FAULT_URI = NAMESPACE_URI + "/fault";
    
    public static final QName FROM_QNAME = 
        new QName(NAMESPACE_URI, "From", PREFIX);

    public static final String IS_REFERENCE_PARAMETER = "IsReferenceParameter";
    
    public static final String IS_REFERENCE_PARAMETER_QNAME = "wsa:IsReferenceParameter";
    
    public static final QName MESSAGE_ID_QNAME = 
        new QName(NAMESPACE_URI, "MessageID", PREFIX);
    
    public static final QName METADATA_QNAME = 
        new QName(NAMESPACE_URI, "Metadata", PREFIX);
    
    public static final QName PARAMETERS_QNAME = 
        new QName(NAMESPACE_URI, "ReferenceParameters", PREFIX);
    
    public static final QName PORT_TYPE_QNAME = 
        new QName(NAMESPACE_URI, "PortType", PREFIX);
    
    public static final QName RELATES_TO_QNAME = 
        new QName(NAMESPACE_URI, "RelatesTo", PREFIX);
    
    public static final String RELATIONSHIP_TYPE = "RelationshipType";
    
    public static final String REPLY_RELATIONSHIP = PREFIX + ":Reply";
    
    public static final QName REPLY_RELATIONSHIP_QNAME = 
        new QName(NAMESPACE_URI, "Reply", PREFIX);
    
    public static final QName REPLY_TO_QNAME = 
        new QName(NAMESPACE_URI, "ReplyTo", PREFIX);
    
    public static final QName SERVICE_NAME_QNAME = 
        new QName(NAMESPACE_URI, "ServiceName", PREFIX);

    public static final String SERVICE_PORT_NAME = "PortName";
    
    public static final QName TO_QNAME = 
        new QName(NAMESPACE_URI, "To", PREFIX);
    
    /**
     * 
     * The anonymous EPR - this can be used for messages going through 
     * firewalls or situations where the source doesn't want to receive 
     * the reply. Because this EPR is the same no matter where it is 
     * being "sent", we can share one instance of it with all components.
     * 
     */
    public static final EndpointReference ANONYMOUS_EPR = 
        new EndpointReference(URI.create(ANONYMOUS_URI));
}
