/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.addressing.soap;

/**
 *
 * SoapMonitor is a supplemental interface for SOAP clients that wish 
 * to support TCP/SOAP monitoring without modifying server-side code. 
 * Services that use WS-Addressing for routing may find it hard to do 
 * SOAP monitoring because WS-A data is used for routing and resource 
 * identification (so changing a port number equates to changing an 
 * identifier).
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface SoapMonitor
{
    /**
     * 
     * @return The port to which messages are being sent when TCP/SOAP 
     *         monitoring is being used. When no monitoring is used (normal 
     *         mode), this returns -1.
     *
     */
    int getSoapMonitorPort();

    /**
     * 
     * @return True if messages are being redirected to a SOAP monitor port.
     *
     */
    boolean isUsingSoapMonitor();

    /**
     * 
     * Causes the SoapClient to send messages to the given port. This does 
     * <b>not</b> change the port number in the WS-A EPR found in the SOAP 
     * headers. The receiver will have no idea it is taking part in SOAP 
     * monitoring. Only the original HTTP GET will have a different port.
     *
     * @param monitorPort
     *        A positive integer - 0 to 65535.
     *
     */
    void startSoapMonitor(int monitorPort);

    /**
     * 
     * If SOAP monitoring was in use, the client will revert back to 
     * sending the messages to the port in the EPR's wsa:Address. If 
     * SOAP monitoring was not in use, the call is a no-op.
     *
     */
    void stopSoapMonitor();
}
