/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws;

import org.w3c.dom.Element;

import org.apache.muse.ws.resource.WsResource;

/**
 *
 * CorrelationFactory is a device for creating correlation expressions from 
 * their XML definitions without having to reference concrete expression types.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface CorrelationFactory
{
    /**
     * 
     * @param dialect
     * 
     * @return True if the factory can create Correlations of the given type.
     *
     */
    boolean hasDialect(String dialect);
    
    /**
     * 
     * Parses the given Element and creates a complete Correlation expression 
     * that can be evaluated against any WS-RF resource.
     *
     * @param owner
     *        The local resource that is implementing CorrelatableProperties.
     * 
     * @param xml
     *        The DOM Element representing the expression. This fragment 
     *        should have a root element whose QName is the MUWS (Part 1) 
     *        CorrelatableProperties and which has a 'Dialect' attribute. 
     *        The latter will be used to determine the type of Correlation 
     *        to create.
     * 
     * @return A Correlation that can be evaluated against any WS-RF resource.
     *
     */
    Correlation newInstance(WsResource resource, Element xml);
}
