/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws;

import java.util.Date;

import javax.xml.namespace.QName;

import org.apache.muse.ws.resource.basefaults.BaseFault;

/**
 *
 * Metrics is an interface that represents the WSDM Metrics capability. It 
 * provides access to the one Metrics property (muws2:CurrentTime) along with 
 * methods for reading and modifying metrics based on existing properties. 
 * Implementations of this capability may provide varying levels of support 
 * for the initialization of updating of metric metadata.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface Metrics extends ManageabilityCapability
{
    QName[] PROPERTIES = new QName[]{
        MuwsConstants.CURRENT_TIME_QNAME
    };
    
    /**
     * 
     * @return The current time, according to the resource or its manager.
     * 
     */
    Date getCurrentTime() 
        throws BaseFault;
    
    /**
     * 
     * @param propertyQName
     *        The name of the property that is also defined as a metric.
     * 
     * @return The collection of metric metadata for the property, or null if 
     *         the property does not exist.
     *
     */
    Metric getMetric(QName propertyQName);
}
