/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws;

import javax.xml.namespace.QName;
/**
 *
 * MuwsConstants is a collection of properties that is useful when programming 
 * against the WSDM MUWS spec (parts 1 and 2), v1.1.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class MuwsConstants
{
    /**
     * 
     * The base for all WSDM capability URIs.
     * 
     */
    public static final String BASE_CAPABILITIES_URI = 
        "http://docs.oasis-open.org/wsdm/muws/capabilities";
    
    /**
     * 
     * The WSDM Advertisement namespace URI.
     * 
     */
    public static final String ADVERTISEMENT_URI = 
        BASE_CAPABILITIES_URI + "/Advertisement";
    
    /**
     * 
     * The WSDM ManageabilityCharacteristics namespace URI.
     * 
     */
    public static final String CHARACTERISTICS_URI = 
        BASE_CAPABILITIES_URI + "/ManageabilityCharacteristics";

    /**
     * 
     * The WSDM Configuration namespace URI.
     * 
     */
    public static final String CONFIGURATION_URI = 
        BASE_CAPABILITIES_URI + "/Configuration";
    
    /**
     * 
     * The WSDM CorrelatableProperties namespace URI.
     * 
     */
    public static final String CORRELATABLE_URI = 
        BASE_CAPABILITIES_URI + "/CorrelatableProperties";
    
    /**
     * 
     * The WSDM Description namespace URI.
     * 
     */
    public static final String DESCRIPTION_URI = 
        BASE_CAPABILITIES_URI + "/Description";

    /**
     * 
     * The WSDM Identity namespace URI.
     * 
     */
    public static final String IDENTITY_URI = 
        BASE_CAPABILITIES_URI + "/Identity";

    /**
     * 
     * The WSDM Metrics namespace URI.
     * 
     */
    public static final String METRICS_URI = 
        BASE_CAPABILITIES_URI + "/Metrics";
    
    /**
     * 
     * The WSDM OperationalStatus namespace URI.
     * 
     */
    public static final String OP_STATUS_URI = 
        BASE_CAPABILITIES_URI + "/OperationalStatus";
    
    /**
     * 
     * The WSDM Relationships namespace URI.
     * 
     */
    public static final String RELATIONSHIPS_URI = 
        BASE_CAPABILITIES_URI  + "/Relationships";
    
    /**
     * 
     * The WSDM RelationshipResource namespace URI.
     * 
     */
    public static final String RELATIONSHIP_RESOURCE_URI = 
        BASE_CAPABILITIES_URI + "/RelationshipResource";

    /**
     * 
     * The WSDM State namespace URI.
     * 
     */
    public static final String STATE_URI = 
        BASE_CAPABILITIES_URI + "/State";
    
    /**
     * 
     * The CorrelatableProperties "Property Boolean Match" URI.
     * 
     */
    public static final String PBM_URI = 
        "http://docs.oasis-open.org/wsdm/2004/12/pbm";
    
    public static final String PBM_PREFIX = "pbm";
    
    public static final QName MATCH_QNAME = 
        new QName(PBM_URI, "Match", PBM_PREFIX);
    
    public static final QName MATCH_ALL_QNAME = 
        new QName(PBM_URI, "MatchAll", PBM_PREFIX);
    
    public static final QName MATCH_ANY_QNAME = 
        new QName(PBM_URI, "MatchAny", PBM_PREFIX);
    
    public static final String DIALECT = "Dialect";
    
    public static final String NEGATIVE = "NegativeAssertionPossible";
    
    /**
     * 
     * The prefix of the WS-N TopicNamespace for all WSDM Topics.
     * 
     */
    public static final String MUWS_EVENTS_PREFIX = "muws-events";
    
    /**
     * 
     * The namespace of the WS-N TopicNamespace for all WSDM Topics.
     * 
     */
    public static final String MUWS_EVENTS_URI = "http://docs.oasis-open.org/wsdm/muwse-2.xml";
    
    public static final String MUWS_TOPIC_NS = MUWS_EVENTS_URI;

    public static final String MUWS_WSDL_URI = "http://docs.oasis-open.org/wsdm/muws-2.wsdl";
    
    public static final String MUWS_P1_PREFIX = "muws1";

    public static final String MUWS_P1_URI = "http://docs.oasis-open.org/wsdm/muws1-2.xsd";

    public static final String MUWS_P2_PREFIX = "muws2";
    
    public static final String MUWS_P2_URI = "http://docs.oasis-open.org/wsdm/muws2-2.xsd";
    
    public static final QName RESOURCE_ID_QNAME = 
        new QName(MUWS_P1_URI, "ResourceId", MUWS_P1_PREFIX);
    
    public static final QName MANAGEABILITY_EPR_QNAME = 
        new QName(MUWS_P1_URI, "ManageabilityEndpointReference", MUWS_P1_PREFIX);
    
    /**
     * 
     * MUWS Capability name, for defining capabilities in metadata. Don't 
     * confuse this with the ManageabilityCharacteristics property name: 
     * ManageabilityCapability.
     * 
     */
    public static final QName CAPABILITY_QNAME = 
        new QName(MUWS_P2_URI, "Capability", MUWS_P2_PREFIX);
    
    //
    // WSDM Metrics names and attributes
    //
    
    public static final QName CURRENT_TIME_QNAME = 
        new QName(MUWS_P2_URI, "CurrentTime", MUWS_P2_PREFIX);
    
    public static final QName METRIC_ATTRIBUTES_QNAME = 
        new QName(MUWS_P2_URI, "MetricAttributes", MUWS_P2_PREFIX);
    
    public static final String RESET_AT = "ResetAt";
    public static final String DURATION = "Duration";
    public static final String LAST_UPDATED = "LastUpdated";
    
    public static final QName METRIC_GROUP_QNAME = 
        new QName(MUWS_P2_URI, "MetricGroup", MUWS_P2_PREFIX);
    
    public static final QName CALC_INTERVAL_QNAME = 
        new QName(MUWS_P2_URI, "CalculationInterval", MUWS_P2_PREFIX);
    
    public static final QName CHANGE_TYPE_QNAME = 
        new QName(MUWS_P2_URI, "ChangeType", MUWS_P2_PREFIX);
    
    public static final String COUNTER = "Counter";
    public static final String GAUGE = "Gauge";
    public static final String UNKNOWN = "Unknown";
    
    public static final QName GATHERING_QNAME = 
        new QName(MUWS_P2_URI, "GatheringTime", MUWS_P2_PREFIX);
    
    public static final String ON_CHANGE = "OnChange";
    public static final String ON_DEMAND = "OnDemand";
    public static final String PERIODIC = "Periodic";
    
    public static final QName TIME_SCOPE_QNAME = 
        new QName(MUWS_P2_URI, "TimeScope", MUWS_P2_PREFIX);
    
    public static final String INTERVAL = "Interval";
    public static final String POINT_IN_TIME = "PointInTime";
    public static final String SINCE_RESET = "SinceReset";
    
    //
    // WSDM Relationships names and attributes
    //
    
    public static final String QUERY_RELATIONSHIPS_URI = 
        RELATIONSHIPS_URI + "/QueryRelationshipsByType";
    
    public static final QName RELATIONSHIP_QNAME = 
        new QName(MUWS_P2_URI, "Relationship", MUWS_P2_PREFIX);
    
    public static final QName NAME_QNAME = 
        new QName(MUWS_P2_URI, "Name", MUWS_P2_PREFIX);
    
    public static final QName TYPE_QNAME = 
        new QName(MUWS_P2_URI, "Type", MUWS_P2_PREFIX);
    
    public static final QName ACCESS_EPR_QNAME = 
        new QName(MUWS_P2_URI, "AccessEndpointReference", MUWS_P2_PREFIX);
    
    public static final QName PARTICIPANT_QNAME = 
        new QName(MUWS_P2_URI, "Participant", MUWS_P2_PREFIX);
        
    public static final QName ROLE_QNAME = 
        new QName(MUWS_P2_URI, "Role", MUWS_P2_PREFIX);
    
    public static final QName QUERY_RELATIONSHIPS_QNAME = 
        new QName(MUWS_P2_URI, "QueryRelationshipsByType", MUWS_P2_PREFIX);
    
    public static final QName QUERY_RESPONSE_QNAME = 
        new QName(MUWS_P2_URI, "QueryRelationshipsByTypeResponse", MUWS_P2_PREFIX);
    
    public static final QName REQUESTED_TYPE_QNAME = 
        new QName(MUWS_P2_URI, "RequestedType", MUWS_P2_PREFIX);
    
    //
    // WSDM Advertisement names and attributes
    //
    
    public static final QName CREATE_NOTIFICATION_QNAME = 
        new QName(MUWS_P2_URI, "CreationNotification", MUWS_P2_PREFIX);

    public static final QName DESTROY_NOTIFICATION_QNAME = 
        new QName(MUWS_P2_URI, "DestructionNotification", MUWS_P2_PREFIX);
    
    //
    // WSDM Topic creation
    //
    
    public static final QName ADV_ME_CREATION_TOPIC = 
        new QName(MUWS_TOPIC_NS, "ManageabilityEndpointCreation", MUWS_EVENTS_PREFIX);

    public static final QName ADV_MR_CREATION_TOPIC = 
        new QName(MUWS_TOPIC_NS, "ManageableResourceCreation", MUWS_EVENTS_PREFIX);
    
    public static final QName ADV_ME_DESTRUCTION_TOPIC = 
        new QName(MUWS_TOPIC_NS, "ManageabilityEndpointDestruction", MUWS_EVENTS_PREFIX);

    public static final QName ADV_MR_DESTRUCTION_TOPIC = 
        new QName(MUWS_TOPIC_NS, "ManageableResourceDestruction", MUWS_EVENTS_PREFIX);
    
    public static final QName CHARACTERISTICS_TOPIC = 
        new QName(MUWS_TOPIC_NS, "ManageabilityCharacteristicsCapability", MUWS_EVENTS_PREFIX);
    
    public static final QName CONFIGURATION_TOPIC = 
        new QName(MUWS_TOPIC_NS, "ConfigurationCapability", MUWS_EVENTS_PREFIX);
    
    public static final QName CORRELATABLE_TOPIC = 
        new QName(MUWS_TOPIC_NS, "CorrelatablePropertiesCapability", MUWS_EVENTS_PREFIX);
    
    public static final QName DESCRIPTION_TOPIC = 
        new QName(MUWS_TOPIC_NS, "DescriptionCapability", MUWS_EVENTS_PREFIX);
    
    public static final QName IDENTITY_TOPIC = 
        new QName(MUWS_TOPIC_NS, "IdentityCapability", MUWS_EVENTS_PREFIX);
    
    public static final QName METRICS_TOPIC = 
        new QName(MUWS_TOPIC_NS, "MetricsCapability", MUWS_EVENTS_PREFIX);
    
    public static final QName OP_STATUS_TOPIC = 
        new QName(MUWS_TOPIC_NS, "OperationalStatusCapability", MUWS_EVENTS_PREFIX);
    
    public static final QName RELATIONSHIPS_TOPIC = 
        new QName(MUWS_TOPIC_NS, "RelationshipsCapability", MUWS_EVENTS_PREFIX);

    public static final QName RELATIONSHIP_RESOURCE_TOPIC = 
        new QName(MUWS_TOPIC_NS, "RelationshipResourceCapability", MUWS_EVENTS_PREFIX);
    
    public static final QName STATE_TOPIC = 
        new QName(MUWS_TOPIC_NS, "StateCapability", MUWS_EVENTS_PREFIX);
    
    //
    // Resource properties for WSDM capabilities
    //
    
    public static final QName CORRELATABLE_QNAME = 
        new QName(MUWS_P1_URI, "CorrelatableProperties", MUWS_P1_PREFIX);
    
    public static final QName CAPTION_QNAME = 
        new QName(MUWS_P2_URI, "Caption", MUWS_P2_PREFIX);
    
    public static final QName DESCRIPTION_QNAME = 
        new QName(MUWS_P2_URI, "Description", MUWS_P2_PREFIX);
    
    public static final QName VERSION_QNAME = 
        new QName(MUWS_P2_URI, "Version", MUWS_P2_PREFIX);
    
    public static final QName MANAGEABILITY_CAPABILITY_QNAME = 
        new QName(MUWS_P1_URI, "ManageabilityCapability", MUWS_P1_PREFIX);

    public static final QName OP_STATUS_QNAME = 
        new QName(MUWS_P2_URI, "OperationalStatus", MUWS_P2_PREFIX);
    
    public static final QName STATE_QNAME = 
        new QName(MUWS_P2_URI, "State", MUWS_P2_PREFIX);
    
    public static final QName TRANSITION_QNAME = 
        new QName(MUWS_P2_URI, "StateTransition", MUWS_P2_PREFIX);
    
    public static final QName PREVIOUS_QNAME = 
        new QName(MUWS_P2_URI, "PreviousState", MUWS_P2_PREFIX);

    public static final QName ENTERED_QNAME = 
        new QName(MUWS_P2_URI, "EnteredState", MUWS_P2_PREFIX);
    
    public static final String TIME = "Time";
}
