/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws;

import javax.xml.namespace.QName;

import org.apache.muse.ws.resource.basefaults.BaseFault;

/**
 *
 * This interface represents the WSDM State capability. It defines two 
 * properties, muws2:State and muws2:StateTransition, which are the resource's 
 * current state and the record of its last state change, respectively. 
 * <br><br>
 * Unlike {@linkplain OperationalStatus OperationalStatus}, which provides an 
 * enumeration of status values, the state types are not standard - the 
 * implementation must define them using XML Schema and the 
 * {@linkplain StateType StateType interface}.
 * 
 * @author Dan Jemiolo (danj)
 * 
 */

public interface State extends ManageabilityCapability
{
    QName[] PROPERTIES = new QName[]{
        MuwsConstants.STATE_QNAME, 
        MuwsConstants.TRANSITION_QNAME 
    };
    
    /**
     * 
     * @return The current state of the owning resource; state types may 
     *         have subtypes, and these values should be considered when 
     *         evaluating the state.
     * 
     */
    StateType getState()
        throws BaseFault;
    
    /**
     * 
     * @return The record of the last state change experienced by the 
     *         owning resource.
     * 
     */
    StateTransition getStateTransition()
        throws BaseFault;
    
    /**
     * 
     * @param state
     *        The current state of the owning resource; this state may have 
     *        subtypes. Changing the State will alter the muws2:StateTransition 
     *        property as well.
     * 
     * @throws BaseFault
     *         <ul>
     *         <li>If the state type is not a valid value (as specified in 
     *         the resource's RMD).</li>
     *         <li>If the proposed state-to-state transition is not allowed.</li>
     *         </ul>
     *
     */
    void setState(StateType state)
        throws BaseFault;
}
