/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws.impl;

import javax.xml.namespace.QName;

import org.w3c.dom.Element;

import org.apache.muse.ws.dm.muws.Metric;
import org.apache.muse.ws.resource.properties.listeners.PropertyReadListener;

/**
 *
 * MetricOnDemandListener is a simple property listener that makes sure an 
 * OnDemand metric's timestamps are updated for each property read that 
 * occurs. Because OnDemand metrics are collected on a need-to-know basis, 
 * we must update metric metadata to reflect new values even if they didn't 
 * come from a property insert/update/etc.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class MetricOnDemandListener implements PropertyReadListener
{
    private Metric _metric = null;
    
    public MetricOnDemandListener(Metric metric)
    {
        _metric = metric;
    }

    public QName getPropertyName()
    {
        return _metric.getName();
    }

    public Element[] readRequested(Element[] properties)
    {
        //
        // tell the metric to update its timestamps
        //
        _metric.update();
        return properties;
    }
}
