/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws.impl;

import javax.xml.namespace.QName;

import org.w3c.dom.Element;

import org.apache.muse.ws.dm.muws.Metric;
import org.apache.muse.ws.resource.properties.listeners.PropertyChangeListener;

/**
 *
 * MetricUpdateListener is a simple property listener that pings the Metric 
 * data structure to record a timestamp for the metric update. This timestamp 
 * update is important because it affects the value(s) of the metric attributes 
 * that decorate a property's definition.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class MetricUpdateListener implements PropertyChangeListener
{
    private Metric _metric = null;
    
    public MetricUpdateListener(Metric metric)
    {
        _metric = metric;
    }

    public QName getPropertyName()
    {
        return _metric.getName();
    }

    public void propertyChanged(Element oldValue, Element newValue)
    {
        //
        // tell the metric to update its timestamps
        //
        _metric.update();
    }
}
