/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws.impl;

import java.util.ArrayList;

import javax.xml.namespace.QName;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import org.apache.muse.util.messages.Messages;
import org.apache.muse.util.messages.MessagesFactory;
import org.apache.muse.util.xml.XmlUtils;
import org.apache.muse.ws.dm.muws.StateType;
import org.apache.muse.ws.dm.muws.MuwsConstants;
import org.apache.muse.ws.dm.muws.State;

/**
 *
 * SimpleStateType represents state values for the {@linkplain State State} 
 * capability. It is commonly used to create static fields representing 
 * an enumeration of well-defined states.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class SimpleStateType implements StateType
{
    //
    // Used to lookup all exception messages
    //
    private static Messages _MESSAGES = MessagesFactory.get(SimpleStateType.class);
    
    //
    // The user-defined state names - this will be the element names 
    // in the XML representation
    //
    private QName[] _values = null;
    
    public SimpleStateType(Element xml)
    {
        ArrayList valuesList = new ArrayList();
        Element next = XmlUtils.getFirstElement(xml);
        
        while (next != null)
        {
            valuesList.add(next);
            next = XmlUtils.getFirstElement(next);
        }
        
        _values = new QName[valuesList.size()];
        _values = (QName[])valuesList.toArray(_values);
    }
    
    public SimpleStateType(QName[] values)
    {
        if (values == null)
            throw new NullPointerException(_MESSAGES.get("NullStateName"));
        
        _values = values;
    }
    
    public QName[] getValues()
    {
        return _values;
    }
    
    public Element toXML()
    {
        return toXML(XmlUtils.EMPTY_DOC);
    }
    
    public Element toXML(Document doc)
    {
        if (doc == null)
            throw new NullPointerException(_MESSAGES.get("NullDocument"));
        
        //
        // the state value is wrapped in a wsdm:State element
        //
        Element root = XmlUtils.createElement(doc, MuwsConstants.STATE_QNAME);
        
        Element parent = root;
        QName[] childNames = getValues();
        
        for (int n = 0; n < childNames.length; ++n)
        {
            Element child = XmlUtils.createElement(doc, childNames[n]);
            parent.appendChild(child);
            parent = child;
        }
        
        return root;
    }
}
