/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws.events;

import org.w3c.dom.Element;

import org.apache.muse.util.xml.XmlSerializable;

/**
 *
 * WefFactory defines methods needed to instantiate "blank" WEF events and 
 * their sub-components, as well as events and sub-components that exist as 
 * from XML fragments. The methods that create objects from XML require that 
 * the XML fragments be schema-compliant and correspond to the given WEF 
 * schema element (i.e., createSubstitutableMessage() takes 
 * <em>muws2:SubstitutableMessage</em>).
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface WefFactory
{
    Component createComponent();
    
    Component createComponent(Element componentXML);
    
    ComponentAddress createComponentAddress();
    
    ComponentAddress createComponentAddress(Element addressXML);
    
    ComponentAddress createComponentAddress(XmlSerializable addressData);
    
    ManagementEvent createEvent();

    ManagementEvent createEvent(Element eventXML);
    
    SubstitutableMessage createSubstitutableMessage();
    
    SubstitutableMessage createSubstitutableMessage(Element messageXML);

    Situation createSituation();

    Situation createSituation(Element situationXML);
}
