/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws.events.impl;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

import javax.xml.namespace.QName;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import org.apache.muse.util.xml.XmlUtils;
import org.apache.muse.ws.dm.muws.events.ExtendedElements;

/**
 * 
 * @author Dan Jemiolo (danj)
 *  
 */

public class AbstractExtendedElements implements ExtendedElements
{
    private Collection _extendedElements = new ArrayList();

    public final void addExtendedElement(Element xml)
    {
        _extendedElements.add(xml);
    }

    public final void addExtendedElement(QName elementName, Object elementValue)
    {
        addExtendedElement(XmlUtils.createElement(elementName, elementValue));
    }

    protected void appendExtendedElements(Element xml)
    {
        Document doc = xml.getOwnerDocument();
        Iterator i = getExtendedElements().iterator();

        while (i.hasNext())
        {
            Element next = (Element)i.next();
            next = (Element)doc.importNode(next, true);
            xml.appendChild(next);
        }
    }
    
    public final Collection getExtendedElements()
    {
        return _extendedElements;
    }
    
    public final Collection getExtendedElements(QName elementName)
    {
        Collection results = new ArrayList();
        
        Iterator i = getExtendedElements().iterator();
        
        while (i.hasNext())
        {
            Element next = (Element)i.next();
            QName nextName = XmlUtils.getElementQName(next);
            
            if (nextName.equals(elementName))
                results.add(next);
        }
        
        return results;
    }
}
