/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.notification;

import org.apache.muse.util.xml.XmlSerializable;

/**
 * 
 * Filter is a data structure used by the WS-Notification Subscribe operation 
 * to allow clients to control how many and what type of messages they receive 
 * from a resource. Instances of this type will be used by a resource's WS-N 
 * implementation to determine if a message that has been published should be 
 * sent to a given subscriber.
 * <br><br>
 * WS-N v1.3 defines three filter types: message, topic, and properties. Each 
 * is represented in Muse's default implementation of WS-N.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface Filter extends XmlSerializable
{
    /**
     * 
     * @param message
     * 
     * @return True if the content of the message passes the filter tests (and, 
     *         consequently, should be sent to the subscriber that created the 
     *         filter).
     *
     */
    boolean accepts(NotificationMessage message);
}
