/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.notification;

import org.apache.muse.ws.addressing.soap.SoapFault;

/**
 *
 * NotificationMessageListener is an event listener that allows a consumer 
 * resource to filter incoming messages by topic. If a resource uses the 
 * {@linkplain org.apache.muse.ws.notification.NotificationConsumer NotificationConsumer} 
 * capability, it can register listeners that will execute code whenever a new 
 * message is received that matches the criteria of the listener.
 *
 * @author Dan Jemiolo (danj)
 * 
 * @see org.apache.muse.ws.notification.NotificationConsumer#addMessageListener(NotificationMessageListener)
 *
 */

public interface NotificationMessageListener
{
    /**
     * 
     * @param message
     * 
     * @return True if the listener's process() method should be called in 
     *         response to this message.
     *
     */
    boolean accepts(NotificationMessage message);
    
    /**
     * 
     * This method is invoked ('fired') by the WS-N implementation whenever 
     * a message is received that matches the criteria (accepts()) of the 
     * listener.
     * 
     * @param message
     *
     */
    void process(NotificationMessage message)
        throws SoapFault;
}
