/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.notification;

import org.apache.muse.ws.addressing.EndpointReference;
import org.apache.muse.ws.notification.faults.UnableToCreatePullPointFault;
import org.apache.muse.ws.resource.WsResourceCapability;

/**
 * 
 * PullPointCreation is an interface that represents the WS-Notification 
 * PullPointCreation port type; it is based on WS-N v1.3. This capability 
 * must be used by a resource that is deployed along side a separate pullpoint 
 * resource type.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface PullPointCreation extends WsResourceCapability
{
    /**
     * 
     * Instantiates a new instance of a pullpoint resource that can be 
     * used to store messages from one or more resources.
     * 
     * @return The EPR of the new pullpoint resource.
     *
     */
    EndpointReference createPullPoint()
        throws UnableToCreatePullPointFault;
}
