/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.notification;

import org.apache.muse.core.Initialization;
import org.apache.muse.core.Shutdown;
import org.apache.muse.ws.notification.faults.UnableToGetMessagesFault;
import org.apache.muse.ws.resource.basefaults.BaseFault;

/**
 * 
 * PullPointDataStore is an interface to a persistent data store that is used 
 * by pullpoint resources to keep messages until they are retrieved using the 
 * PullPoint.getMessages() method.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface PullPointDataStore extends Initialization, Shutdown
{
    void addMessage(NotificationMessage message)
        throws BaseFault;

    /**
     * 
     * @param maxNumber
     *        The maximum number of messages that should be returned by the method.
     *        
     * @return Zero or more messages (with a maximum specified by the parameter) 
     *         that have been stored by the pullpoint. Once the messages are 
     *         returned in this operation, they should not be included in 
     *         responses to future requests.
     *
     */
    NotificationMessage[] getMessages(int maxNumber)
        throws UnableToGetMessagesFault;
}
