/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.notification.topics;

import java.util.Collection;

import org.apache.muse.util.xml.XmlSerializable;
import org.apache.muse.ws.resource.basefaults.BaseFault;

/**
 * 
 * TopicNamespace is an interface that represents the wsnt:TopicNamespace data 
 * structure described in WS-Notification v1.3 and WS-Topics v1.3.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface TopicNamespace extends XmlSerializable
{
    /**
     * 
     * Adds a root topic to the namespace.
     * 
     * @param topic
     *
     */
    void addTopic(Topic topic) 
        throws BaseFault;

    /**
     * 
     * @return The local name of the topic namespace.
     *
     */
    String getName();

    /**
     * 
     * @return All of the topics in the namespace that don't have a parent topic.
     *
     */
    Collection getRootTopics();

    /**
     * 
     * @return The namespace URI that represents the topic namespace.
     *
     */
    String getTargetNamespace();

    /**
     * 
     * @param topicName
     * 
     * @return The root topic with the given name, or null if no such topic exists.
     *
     */
    Topic getTopic(String topicName);

    /**
     * 
     * @param topicName
     * 
     * @return True if the namespace has a topic with the given name.
     *
     */
    boolean hasTopic(String topicName);
    
    void removeTopic(String topicName);

    void setName(String name);
}
