/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.notification.impl;

import org.apache.muse.util.xml.XPathUtils;
import org.apache.muse.ws.notification.faults.InvalidMessageContentExpressionFault;

/**
 * 
 * PublishAllMessagesFilter is a specialied MessagePatternFilter that matches 
 * all messages by using a wildcard XPath ('*'). It is a singleton because 
 * the XPath pattern is static and the filter evaluation is stateless.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class PublishAllMessagesFilter extends MessagePatternFilter
{
    private static PublishAllMessagesFilter _SINGLETON = null;
    
    /**
     * 
     * Initializes the MessagePatternFilter class with the XPath expression '*'.
     *
     */
    private PublishAllMessagesFilter() 
        throws InvalidMessageContentExpressionFault
    {
        super("*", XPathUtils.NAMESPACE_URI);
    }
    
    public static PublishAllMessagesFilter getInstance()
    {
        try
        {
            if (_SINGLETON == null)
                _SINGLETON = new PublishAllMessagesFilter();
        }
        
        catch (InvalidMessageContentExpressionFault fault)
        {
            throw new RuntimeException(fault.getMessage(), fault);
        }
            
        return _SINGLETON;
    }
}
