/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.metadata;

import javax.xml.namespace.QName;

/**
 *
 * WsrmdConstants is a collection of properties that are useful when programming 
 * against the WS-ResourceMetadata spec. This class uses WS-RMD v1.0.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class WsrmdConstants
{
    /**
     * 
     * The current WS-RMD namespace URI - v1.0.
     * 
     */
    public static final String NAMESPACE_URI = "http://docs.oasis-open.org/wsrf/rmd-1";
    
    public static final String PREFIX = "wsrmd";
    
    //
    // Elements for RMD definitions
    //
    
    public static final QName DESCRIPTOR_QNAME = 
        new QName(NAMESPACE_URI, "MetadataDescriptor", PREFIX);
    
    public static final QName DESCRIPTOR_ATTR_QNAME = 
        new QName(NAMESPACE_URI, "Descriptor", PREFIX);
    
    public static final QName DESCRIPTOR_LOCATION_ATTR_QNAME = 
        new QName(NAMESPACE_URI, "DescriptorLocation", PREFIX);
    
    public static final String NAME = "name";
    
    public static final String INTERFACE = "interface";
    
    public static final String WSDL_LOCATION = "wsdlLocation";
    
    public static final QName PROPERTY_QNAME = 
        new QName(NAMESPACE_URI, "Property", PREFIX);
    
    //
    // Attributes for wsrmd:Property definitions
    //
    
    public static final String MODIFIABILITY = "modifiability";
    public static final String READ_ONLY = "read-only";
    public static final String READ_WRITE = "read-write";

    public static final String MUTABILITY = "mutability";
    public static final String APPENDABLE = "appendable";
    public static final String CONSTANT = "constant";
    public static final String MUTABLE = "mutable";

    public static final QName INITIAL_VALUES_QNAME = 
        new QName(NAMESPACE_URI, "InitialValues", PREFIX);

    public static final QName STATIC_VALUES_QNAME = 
        new QName(NAMESPACE_URI, "StaticValues", PREFIX);

    public static final QName VALID_VALUES_QNAME = 
        new QName(NAMESPACE_URI, "ValidValues", PREFIX);
    
    public static final QName VALID_RANGE_QNAME = 
        new QName(NAMESPACE_URI, "ValidValueRange", PREFIX);
    
    public static final String LOWER_BOUND = "lowerBound";
    public static final String UPPER_BOUND = "upperBound";
}
