/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.properties.get.ext;

import javax.xml.namespace.QName;

import org.apache.muse.ws.resource.basefaults.BaseFault;
import org.apache.muse.ws.resource.properties.get.faults.InvalidResourcePropertyQNameFault;

/**
 *
 * GetResourcePropertyExtensions is a collection of convenience methods that 
 * can be added onto a WS-RP implementation.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface GetResourcePropertyExtensions
{
    /**
     * 
     * Returns zero or more instances of the given property, deserialized 
     * into instances of the given type. This method differs from 
     * getResourceProperty(QName) in that it returns POJOs rather than XML.
     *
     * @param qname
     *        The name of the property to find.
     * 
     * @param type
     *        The type of the property instances returned by this method. 
     *        Every object in the returned array can be cast to this type.
     * 
     * @return An array of objects, where each object is an instance of the 
     *         property named. There is no guarantee that the objects are 
     *         the internal data structures used by the WS-RP document. The 
     *         objects should be the POJO equivalent of the Elements returned 
     *         by getResourceProperty(QName).
     * 
     * @throws BaseFault
     *         <ul>
     *         <li>If the property is undefined in the document's schema. This 
     *         is <b>not</b> the same as finding zero instances of a defined 
     *         property.</li>
     *         <li>If there is an error creating instances of the given type 
     *         using the property values found.</li>
     *         </ul>
     * 
     * @see org.apache.muse.ws.resource.properties.get.GetResourceProperty
     *
     */
    Object getPropertyAsObject(QName qname, Class type)
        throws InvalidResourcePropertyQNameFault, BaseFault;
}
