/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.properties.listeners;

import javax.xml.namespace.QName;

import org.w3c.dom.Element;

import org.apache.muse.ws.resource.basefaults.BaseFault;

/**
 *
 * PropertyReadListener describes a type of property listener that is 
 * invoked before a property read request is completed (through the WS-RP 
 * GetResourceProperty and GetMultipleResourceProperties operations). Listeners 
 * can react to the read request in any way: the read can be prevented by 
 * throwing an exception, the value returned to the reader can be modified, etc. 
 * This is very useful when defining "dynamic properties", properties that change 
 * constantly and whose values are only updated when a read request is made.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface PropertyReadListener
{
    /**
     * 
     * @return The name of the property to monitor.
     *
     */
    QName getPropertyName();
    
    /**
     * 
     * @param properties
     *        The actual property values that will be returned to the caller 
     *        at the end of the read operation. WS-RP collections should not 
     *        pass copies of the values to a listener, since that prevents 
     *        the ability to define dynamic property values (properties that 
     *        constantly change and are only updated on read requests).
     *
     */
    Element[] readRequested(Element[] properties)
        throws BaseFault;
}
