/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.properties.query;

import org.w3c.dom.Element;
import org.w3c.dom.Node;

import org.apache.muse.ws.resource.properties.query.faults.InvalidQueryExpressionFault;
import org.apache.muse.ws.resource.properties.query.faults.QueryEvaluationErrorFault;

/**
 * 
 * QueryExpression describes components that can evaluate an XML document 
 * based on a specific query language. An example of such a query language 
 * is XPath 1.0. Evaluation of a query expression on an XML document should 
 * result in a set of DOM Nodes no matter what language is used.
 * 
 * @author Dan Jemiolo (danj)
 *
 */

public interface QueryExpression
{
    /**
     * 
     * @return The URI that defines the query language for this expression.
     *
     */
    String getDialect();
    
    /**
     * 
     * @param wsrpDoc
     *        A resource's WSRP document.
     *        
     * @param query
     *        A query expression in the language described by getDialect().
     *        
     * @return An array of nodes from the given document that match the 
     *         query expression. The array may be empty.
     *
     */
    Node[] evaluate(Element wsrpDoc, String query) 
        throws InvalidQueryExpressionFault, 
               QueryEvaluationErrorFault;
}
