/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.sg;

import java.util.Date;

import org.w3c.dom.Element;

import org.apache.muse.ws.addressing.EndpointReference;
import org.apache.muse.ws.resource.WsResourceCapability;
import org.apache.muse.ws.resource.basefaults.BaseFault;
import org.apache.muse.ws.resource.sg.faults.AddRefusedFault;
import org.apache.muse.ws.resource.sg.faults.ContentCreationFailedFault;
import org.apache.muse.ws.resource.sg.faults.UnsupportedMemberInterfaceFault;

/**
 * 
 *
 * ServiceGroupRegistration contains the optional wsrf-sg:Add operation, which 
 * can be added to resource types that already include the WS-RF 
 * {@linkplain ServiceGroup ServiceGroup capability}. The wsrf-sg:Add operation 
 * exposes to remote clients the ServiceGroup.addEntry() method so that external 
 * components can manage the contents of the service group.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface ServiceGroupRegistration extends WsResourceCapability
{
    /**
     * 
     * @param memberEPR
     *        The EPR of the resource that is being added to the group.
     *        
     * @param content
     *        The current values of the resource properties that are listed 
     *        in the group's membership content rules. This may be null.
     *        
     * @param terminationTime
     *        The time at which the service group entry should be deleted. 
     *        This may be null.
     * 
     * @return The EPR of the resource that represents the new service group entry.
     *
     */
    EndpointReference add(EndpointReference memberEPR, Element content, Date terminationTime)
        throws AddRefusedFault, 
               ContentCreationFailedFault, 
               UnsupportedMemberInterfaceFault, 
               BaseFault;
}
