/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.properties.query.impl;

import javax.xml.namespace.QName;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

import org.apache.muse.util.messages.Messages;
import org.apache.muse.util.messages.MessagesFactory;
import org.apache.muse.ws.resource.properties.WsrpConstants;
import org.apache.muse.util.xml.XmlSerializable;
import org.apache.muse.util.xml.XmlUtils;

/**
 *
 * QueryResponse is a serializer/deserializer for the WS-ResourceProperties 
 * QueryResourceProperties operation's response content.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class QueryResponse implements XmlSerializable
{
    //
    // Used to lookup all exception messages
    //
    private static Messages _MESSAGES = MessagesFactory.get(QueryResponse.class);
    
    //
    // The collection of nodes from the WS-RP document that were retrieved 
    // from a QueryResourceProperties query. These nodes may be from any 
    // part of the document, and are not necessarily representative of whole 
    // property instances. The nodes may be anything from an entire WS-RP 
    // document to individual text nodes.
    //
    private Node[] _results = null;
    
    public QueryResponse(Node[] results)
    {
        if (results == null)
            throw new NullPointerException(_MESSAGES.get("NullNodeArray"));

        for (int n = 0; n < results.length; ++n)
        {
            if (results[n] == null)
            {
                Object[] filler = { new Integer(n) };
                throw new NullPointerException(_MESSAGES.get("NullNodeN", filler));
            }
        }
        
        _results = results;
    }
    
    public Node getItem(int index)
    {
        return _results[index];
    }
    
    public Node[] getItems()
    {
        return _results;
    }
    
    public int getNumberOfItems()
    {
        return _results.length;
    }
    
    public String toString()
    {
        return XmlUtils.toString(toXML(), false);
    }
    
    public Element toXML()
    {
        return toXML(XmlUtils.EMPTY_DOC);
    }
    
    public Element toXML(Document doc)
    {
        if (doc == null)
            throw new NullPointerException(_MESSAGES.get("NullDocument"));
        
        QName qname = WsrpConstants.QUERY_RESPONSE_QNAME;
        Element root = XmlUtils.createElement(doc, qname);
        
        int length = getNumberOfItems();

        for (int n = 0; n < length; ++n)
        {
            Node next = doc.importNode(getItem(n), true);
            root.appendChild(next);
        }
        
        return root;
    }
}
