/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.metadata;

import org.w3c.dom.Element;

import org.apache.muse.core.Capability;

/**
 *
 * MetadataExchange is an interface that represents the WS-MetadataExchange 
 * GetMetadata port type; it is based on WS-MEX 09/04. It does not include 
 * the concept of metadata references, only the direct lookup of metadata 
 * from the resource itself.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface MetadataExchange extends Capability
{
    /**
     * 
     * Returns the XML fragments (sometimes a whole document) that describes 
     * the desired metadata.
     *
     * @param dialect
     *        The URI describing the type of metadata to search for. This 
     *        may be WSDL, RMD, WS-Policy, or others.
     * 
     * @return The XML fragment(s) that describe the desired metadata. If the 
     *         resource has no such metadata, the array is empty.
     *
     */
    Element[] getMetadata(String dialect);
}
