/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.muse.osgi.wsrf.impl;

import org.apache.muse.util.osgi.AbstractResourceManagementImplementation;
import org.apache.muse.util.osgi.CapabilityPair;
import org.osgi.framework.Bundle;
import org.osgi.framework.ServiceFactory;
import org.osgi.framework.ServiceRegistration;

/**
 * WSRFImplementationService is an implementation of the <code>ResourceManagementImplementation</code>
 * service interface for the WSRF Implementation bundle.
 * 
 * @see ResourceManagementImplementation
 * @author Joel Hawkins (joelh)
 *
 */
public class WSRFImplementationService extends AbstractResourceManagementImplementation implements ServiceFactory {
	
	private static final String IMPLEMENTATION_NAME = "wsrf_impl";
	private static final String[] RESOURCE_IMPLEMENTATIONS = 
		{"org.apache.muse.ws.resource.impl.SimpleWsResource"};
	
	private static final String[] capabilityURI = {
		"http://docs.oasis-open.org/wsrf/rlw-2/ImmediateResourceTermination",
		"http://docs.oasis-open.org/wsrf/rlw-2/ScheduledResourceTermination",
		"http://docs.oasis-open.org/wsrf/rp-2/Get",
		"http://docs.oasis-open.org/wsrf/rp-2/Set",
		"http://docs.oasis-open.org/wsrf/rp-2/Query",
		"http://schemas.xmlsoap.org/ws/2004/09/mex/GetMetadata",
		"http://docs.oasis-open.org/wsrf/rmd-1/ResourceMetadataCapability",
		"http://docs.oasis-open.org/wsrf/sgw-2/ServiceGroup",
		"http://docs.oasis-open.org/wsrf/sgw-2/ServiceGroupEntry"
	};
	
	private static final String[] capabilityImplementation = {
		"org.apache.muse.ws.resource.lifetime.impl.SimpleImmediateTermination",
		"org.apache.muse.ws.resource.lifetime.impl.SimpleScheduledTermination",
		"org.apache.muse.ws.resource.properties.get.impl.SimpleGetCapability",
		"org.apache.muse.ws.resource.properties.set.impl.SimpleSetCapability",
		"org.apache.muse.ws.resource.properties.query.impl.SimpleQueryCapability",
		"org.apache.muse.ws.metadata.impl.SimpleMetadataExchange",
		"org.apache.muse.ws.resource.metadata.impl.SimpleResourceMetadataCapability",
		"org.apache.muse.ws.resource.sg.impl.SimpleServiceGroup",
		"org.apache.muse.ws.resource.sg.impl.SimpleEntry"
	};
	
	private static CapabilityPair capabilities[] = {
		new CapabilityPair(capabilityURI[0],capabilityImplementation[0]),
		new CapabilityPair(capabilityURI[1],capabilityImplementation[1]),
		new CapabilityPair(capabilityURI[2],capabilityImplementation[2]),
		new CapabilityPair(capabilityURI[3],capabilityImplementation[3]),
		new CapabilityPair(capabilityURI[4],capabilityImplementation[4]),
		new CapabilityPair(capabilityURI[5],capabilityImplementation[5]),
		new CapabilityPair(capabilityURI[6],capabilityImplementation[6]),
		new CapabilityPair(capabilityURI[7],capabilityImplementation[7]),
		new CapabilityPair(capabilityURI[8],capabilityImplementation[8]),
	};
	
	public WSRFImplementationService(Bundle bundle){
		super(bundle);
		this.implementationName = IMPLEMENTATION_NAME;
		this.resourceImplementationNames = RESOURCE_IMPLEMENTATIONS;
		this.capabilityMappings = capabilities;
	}

	public Object getService(Bundle bundle, ServiceRegistration registration) {
		return this;
	}

	public void ungetService(Bundle bundle, ServiceRegistration registration, Object service) {
	}
}
